__version__ = "3.0.2"
__author__ = "Nico Schlömer"
__author_email__ = "nico.schloemer@gmail.com"
__copyright__ = "Copyright (c) 2015-2019 {} <{}>".format(__author__, __author_email__)
__website__ = "https://github.com/nschloe/meshio"
__license__ = "License :: OSI Approved :: MIT License"
__status__ = "Development Status :: 5 - Production/Stable"
